@@ -1,7 +1,6 @@
 from .geometry import Geometry
 from .point import Point
 from .polygon import Polygon
-from .sampler import Sampler
 from .transform import Transform
 from .box import Box
 from .cylinder import Cylinder
@@ -15,6 +14,3 @@ __all__ = [
     "Box",
     "Cylinder",
 ]
-
-__anthor__ = "PuQing"
-__email__ = "me@puqing.work"
